function [D,R] = loaddata(filename)
% LOADDATA  Loads purchase data from a csv file.
%
%   [D,R] = LOADDATA('purchase.csv') loads the purchase data and returns
%   it in two form. D stores the purchase data as a cell array of string, 
%   one cell per column. R stores the purchase data as a matrix, where the
%   string values have been mapped to integers. Counting records for 
%   sufficient statistics is easier using R than using D.

[fid,msg] = fopen(filename,'r');
if fid < 0 
    error(msg);
end

D = textscan(fid,'%s %s %s %s',-1,'headerLines',1,'delimiter',',');
fclose(fid);

nrecords = length(D{1});
ncolumns = 4;
R = zeros([nrecords ncolumns]);
for i = 1:nrecords
    if strcmp(D{1}(i),'Youth')
        R(i,1) = 1; % Youth
    else
        R(i,1) = 2; % Adult
    end
    
    if strcmp(D{2}(i),'Male')
        R(i,2) = 1; % Male
    else
        R(i,2) = 2; % Female
    end
    
    if strcmp(D{3}(i),'Self-Help')
        R(i,3) = 1; % Self-Help
    else
        R(i,3) = 2; % Cookbook
    end
    
    if strcmp(D{4}(i), 'Dislikes')
        R(i,4) = 1; % Dislikes
    elseif strcmp(D{4}(i), 'Neutral')
        R(i,4) = 2; % Neutral
    else
        R(i,4) = 3; % Likes
    end
end
        